==> micro-website-base-core-2.0.122-sources.jar: com/ptteng/sca/micro/common/client/SubscribeTemplateSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.SubscribeTemplate;
import com.ptteng.micro.common.service.SubscribeTemplateService;

import java.util.List;
import java.util.Map;

public class SubscribeTemplateSCAClient implements SubscribeTemplateService {

    private SubscribeTemplateService subscribeTemplateService;

	public SubscribeTemplateService getSubscribeTemplateService() {
		return subscribeTemplateService;
	}
	
	
	public void setSubscribeTemplateService(SubscribeTemplateService subscribeTemplateService) {
		this.subscribeTemplateService =subscribeTemplateService;
	}
	
	
			   
		@Override
		public Long insert(SubscribeTemplate subscribeTemplate)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.insert(subscribeTemplate);
		          
		
		}	
		  
    	   
		@Override
		public List<SubscribeTemplate> insertList(List<SubscribeTemplate> subscribeTemplateList)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.insertList(subscribeTemplateList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(SubscribeTemplate subscribeTemplate)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.update(subscribeTemplate);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<SubscribeTemplate> subscribeTemplateList)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.updateList(subscribeTemplateList);
		          
		
		}	
		  
    	   
		@Override
		public SubscribeTemplate getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<SubscribeTemplate> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getSubscribeTemplateIdByAppIdAndTemplateId(String appId,String templateId)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdByAppIdAndTemplateId(appId,templateId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getSubscribeTemplateIdsByAppId(String appId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdsByAppId(appId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getSubscribeTemplateIdByAppIdAndCategoryAndType(String appId,Integer category,Integer type)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdByAppIdAndCategoryAndType(appId,category,type);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getSubscribeTemplateIdsByAppIdAndCategory(String appId,Integer category,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdsByAppIdAndCategory(appId,category,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countSubscribeTemplateIdsByAppId(String appId)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.countSubscribeTemplateIdsByAppId(appId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countSubscribeTemplateIdsByAppIdAndCategory(String appId,Integer category)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.countSubscribeTemplateIdsByAppIdAndCategory(appId,category);
	
	
	}
	
		
	
		@Override
	public List<Long> getSubscribeTemplateIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.getSubscribeTemplateIds(start, limit);
	}

	@Override
	public Integer countSubscribeTemplateIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.countSubscribeTemplateIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   subscribeTemplateService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.subscribeTemplateService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}



 
}

==> micro-website-base-core-2.1.5-sources.jar: com/ptteng/sca/micro/common/client/SubscribeTemplateSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.common.client;

import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;
import com.ptteng.micro.common.model.SubscribeTemplate;
import com.ptteng.micro.common.service.SubscribeTemplateService;

import java.util.List;
import java.util.Map;

public class SubscribeTemplateSCAClient implements SubscribeTemplateService {

    private SubscribeTemplateService subscribeTemplateService;

	public SubscribeTemplateService getSubscribeTemplateService() {
		return subscribeTemplateService;
	}
	
	
	public void setSubscribeTemplateService(SubscribeTemplateService subscribeTemplateService) {
		this.subscribeTemplateService =subscribeTemplateService;
	}
	
	
			   
		@Override
		public Long insert(SubscribeTemplate subscribeTemplate)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.insert(subscribeTemplate);
		          
		
		}	
		  
    	   
		@Override
		public List<SubscribeTemplate> insertList(List<SubscribeTemplate> subscribeTemplateList)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.insertList(subscribeTemplateList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(SubscribeTemplate subscribeTemplate)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.update(subscribeTemplate);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<SubscribeTemplate> subscribeTemplateList)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.updateList(subscribeTemplateList);
		          
		
		}	
		  
    	   
		@Override
		public SubscribeTemplate getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<SubscribeTemplate> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getSubscribeTemplateIdByAppIdAndTemplateId(String appId,String templateId)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdByAppIdAndTemplateId(appId,templateId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getSubscribeTemplateIdsByAppId(String appId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdsByAppId(appId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Long  getSubscribeTemplateIdByAppIdAndCategoryAndType(String appId,Integer category,Integer type)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdByAppIdAndCategoryAndType(appId,category,type);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getSubscribeTemplateIdsByAppIdAndCategory(String appId,Integer category,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.getSubscribeTemplateIdsByAppIdAndCategory(appId,category,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countSubscribeTemplateIdsByAppId(String appId)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.countSubscribeTemplateIdsByAppId(appId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countSubscribeTemplateIdsByAppIdAndCategory(String appId,Integer category)throws ServiceException, ServiceDaoException{
		
		return subscribeTemplateService.countSubscribeTemplateIdsByAppIdAndCategory(appId,category);
	
	
	}
	
		
	
		@Override
	public List<Long> getSubscribeTemplateIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.getSubscribeTemplateIds(start, limit);
	}

	@Override
	public Integer countSubscribeTemplateIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.countSubscribeTemplateIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return subscribeTemplateService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   subscribeTemplateService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.subscribeTemplateService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}

	@Override
	public Object getMapListByDynamicCondition(Class aClass, Map<String, Object> map, Integer integer, Integer integer1) throws ServiceException, ServiceDaoException {
		return null;
	}


}
